@@ -1,3 +1,4 @@
+from ConfigParser import ConfigParser
 import convertible
 import os.path
 
@@ -77,6 +78,10 @@ class DomainConfig:
     def save(self, obj):
         convertible.write_json(self.filename, obj)
 
+    def remove(self):
+        if os.path.isfile(self.filename):
+            os.remove(self.filename)
+
 
 class ServiceConfig:
 
@@ -110,4 +115,28 @@ class ServiceConfig:
     def remove(self, name):
         items = self.load()
         new_items = [i for i in items if i.name != name]
-        self.save(new_items)
\ No newline at end of file
+        self.save(new_items)
+
+
+class InsiderConfig:
+
+    def __init__(self, filename):
+        self.parser = ConfigParser()
+        self.parser.read(filename)
+        self.filename = filename
+
+    def update(self, domain, api_url):
+        self.parser.set('redirect', 'domain', domain)
+        self.parser.set('redirect', 'api_url', api_url)
+        with open(self.filename, 'wb') as file:
+            self.parser.write(file)
+
+    def get_redirect_api_url(self):
+        return self.parser.get('redirect', 'api_url')
+
+    def get_redirect_main_domain(self):
+        return self.parser.get('redirect', 'domain')
+
+    def get_cron_period_mins(self):
+        return self.parser.getint('cron', 'period_mins')
+
