@@ -11,6 +11,13 @@ class ServiceUrls:
         self.full_url = "{}://{}/{}".format(service.protocol, self.domain_port, service.url)
 
 
+class ServiceConnection(Service):
+    def __init__(self, service, domain, external_port):
+        Service.__init__(self, service.name, service.protocol, service.type, service.port, service.url)
+        self.domain = domain
+        self.external_port = external_port
+
+
 class Dns:
 
     def __init__(self, api_url, main_domain_name, domain_config, service_config, port_mapper):
@@ -62,6 +69,11 @@ class Dns:
         mapping = self.port_mapper.get(service.port)
         return ServiceUrls(self.full_name(), service, mapping)
 
+    def service_info(self, name):
+        service = self.get_service(name)
+        mapping = self.port_mapper.get(service.port)
+        return ServiceConnection(service, self.full_name(), mapping.external_port)
+
     def sync(self):
         self.port_mapper.sync()
 
